package dev.fitko.fitconnect.core.http;

import dev.fitko.fitconnect.api.config.ApplicationConfig;
import dev.fitko.fitconnect.api.config.BuildInfo;
import org.junit.jupiter.api.Test;
import org.springframework.http.client.InterceptingClientHttpRequestFactory;
import org.springframework.web.client.RestTemplate;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.equalTo;
import static org.junit.jupiter.api.Assertions.*;

class ProxyConfigTest {

    ProxyConfig underTest;

    @Test
    void proxyRestTemplate() {

        // Given
        ApplicationConfig applicationConfig = new ApplicationConfig();
        applicationConfig.setHttpProxyHost("http://testhost.de");
        applicationConfig.setHttpProxyPort(8080);
        applicationConfig.setBuildInfo(new BuildInfo());
        underTest = new ProxyConfig(applicationConfig);

        // When
        final RestTemplate template = underTest.proxyRestTemplate();

        // Then
        assertNotNull(template);
        assertThat(template.getRequestFactory().getClass(), equalTo(InterceptingClientHttpRequestFactory.class));

    }

    @Test
    void hasProxySet() {

        // Given
        ApplicationConfig applicationConfig = new ApplicationConfig();
        applicationConfig.setHttpProxyHost("http://testhost.de");
        applicationConfig.setHttpProxyPort(8080);
        underTest = new ProxyConfig(applicationConfig);

        // When
        final boolean proxySet = underTest.hasProxySet();

        // Then
        assertTrue(proxySet);
    }

    @Test
    void hasProxyNotSet() {

        // Given
        ApplicationConfig applicationConfig = new ApplicationConfig();
        applicationConfig.setHttpProxyHost(null);
        applicationConfig.setHttpProxyPort(0);
        underTest = new ProxyConfig(applicationConfig);

        // When
        final boolean proxySet = underTest.hasProxySet();

        // Then
        assertFalse(proxySet);
    }

    @Test
    void testToString() {

        // Given
        ApplicationConfig applicationConfig = new ApplicationConfig();
        applicationConfig.setHttpProxyHost("http://testhost.de");
        applicationConfig.setHttpProxyPort(8080);
        underTest = new ProxyConfig(applicationConfig);

        // When
        final String configAsString = underTest.toString();

        // Then
        assertEquals("ProxyConfig {host='http://testhost.de', port=8080}", configAsString);
    }
}